==> aws-java-sdk-1.7.1-sources.jar: com/amazonaws/services/elasticmapreduce/model/transform/BootstrapActionDetailJsonUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.elasticmapreduce.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Bootstrap Action Detail JSON Unmarshaller
 */
public class BootstrapActionDetailJsonUnmarshaller implements Unmarshaller<BootstrapActionDetail, JsonUnmarshallerContext> {

    public BootstrapActionDetail unmarshall(JsonUnmarshallerContext context) throws Exception {
        BootstrapActionDetail bootstrapActionDetail = new BootstrapActionDetail();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.currentToken;
        if (token == null) token = context.nextToken();
        if (token == VALUE_NULL) return null;

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("BootstrapActionConfig", targetDepth)) {
                    context.nextToken();
                    bootstrapActionDetail.setBootstrapActionConfig(BootstrapActionConfigJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth) break;
                }
            }

            token = context.nextToken();
        }
        
        return bootstrapActionDetail;
    }

    private static BootstrapActionDetailJsonUnmarshaller instance;
    public static BootstrapActionDetailJsonUnmarshaller getInstance() {
        if (instance == null) instance = new BootstrapActionDetailJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-1.8.9-sources.jar: com/amazonaws/services/elasticmapreduce/model/transform/BootstrapActionDetailJsonUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.elasticmapreduce.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Bootstrap Action Detail JSON Unmarshaller
 */
public class BootstrapActionDetailJsonUnmarshaller implements Unmarshaller<BootstrapActionDetail, JsonUnmarshallerContext> {

    public BootstrapActionDetail unmarshall(JsonUnmarshallerContext context) throws Exception {
        BootstrapActionDetail bootstrapActionDetail = new BootstrapActionDetail();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null) token = context.nextToken();
        if (token == VALUE_NULL) return null;

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("BootstrapActionConfig", targetDepth)) {
                    context.nextToken();
                    bootstrapActionDetail.setBootstrapActionConfig(BootstrapActionConfigJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth) break;
                }
            }

            token = context.nextToken();
        }
        
        return bootstrapActionDetail;
    }

    private static BootstrapActionDetailJsonUnmarshaller instance;
    public static BootstrapActionDetailJsonUnmarshaller getInstance() {
        if (instance == null) instance = new BootstrapActionDetailJsonUnmarshaller();
        return instance;
    }
}
